@@ -1,13 +1,13 @@
+import jax.numpy as jnp
 import logging
 import numpy as np
-from typing import Dict, Optional, Union
+from typing import List, Optional
 
 import autofit as af
 import autoarray as aa
 import autogalaxy as ag
 
-from autolens.analysis.positions import PositionsLHResample
-from autolens.analysis.positions import PositionsLHPenalty
+from autolens.analysis.positions import PositionsLH
 from autolens.lens.tracer import Tracer
 
 from autolens.lens import tracer_util
@@ -22,10 +22,8 @@ logger.setLevel(level="INFO")
 class AnalysisLens:
     def __init__(
         self,
-        positions_likelihood: Optional[
-            Union[PositionsLHResample, PositionsLHPenalty]
-        ] = None,
-        cosmology: ag.cosmo.LensingCosmology = ag.cosmo.Planck15(),
+        positions_likelihood_list: Optional[List[PositionsLH]] = None,
+        cosmology: ag.cosmo.LensingCosmology = None,
     ):
         """
         Analysis classes are used by PyAutoFit to fit a model to a dataset via a non-linear search.
@@ -42,20 +40,18 @@ class AnalysisLens:
         cosmology
             The Cosmology assumed for this analysis.
         """
-        self.cosmology = cosmology
-        self.positions_likelihood = positions_likelihood
+        from autogalaxy.cosmology.wrap import Planck15
+
+        self.cosmology = cosmology or Planck15()
+        self.positions_likelihood_list = positions_likelihood_list
 
     def tracer_via_instance_from(
         self,
         instance: af.ModelInstance,
-        run_time_dict: Optional[Dict] = None,
     ) -> Tracer:
         """
         Create a `Tracer` from the galaxies contained in a model instance.
 
-        If PyAutoFit's profiling tools are used with the analysis class, this function may receive a `run_time_dict`
-        which times how long each set of the model-fit takes to perform.
-
         Parameters
         ----------
         instance
@@ -92,16 +88,14 @@ class AnalysisLens:
             if getattr(instance, "extra_galaxies", None) is not None:
                 return Tracer(
                     galaxies=instance.galaxies + instance.extra_galaxies,
-                    run_time_dict=run_time_dict,
                 )
 
         return Tracer(
             galaxies=instance.galaxies,
             cosmology=cosmology,
-            run_time_dict=run_time_dict,
         )
 
-    def log_likelihood_positions_overwrite_from(
+    def log_likelihood_penalty_from(
         self, instance: af.ModelInstance
     ) -> Optional[float]:
         """
@@ -123,10 +117,22 @@ class AnalysisLens:
         The penalty value of the positions log likelihood, if the positions do not trace close in the source plane,
         else a None is returned to indicate there is no penalty.
         """
-        if self.positions_likelihood is not None:
+        log_likelihood_penalty = jnp.array(0.0)
+
+        if self.positions_likelihood_list is not None:
+
             try:
-                return self.positions_likelihood.log_likelihood_function_positions_overwrite(
-                    instance=instance, analysis=self
-                )
+                for positions_likelihood in self.positions_likelihood_list:
+                    log_likelihood_penalty = (
+                        positions_likelihood.log_likelihood_penalty_from(
+                            instance=instance, analysis=self
+                        )
+                    )
+
+                    log_likelihood_penalty += log_likelihood_penalty
+
+                return log_likelihood_penalty
             except (ValueError, np.linalg.LinAlgError) as e:
                 raise exc.FitException from e
+
+        return log_likelihood_penalty
