@@ -23,7 +23,7 @@ class FitImaging(aa.FitImaging, AbstractFitInversion):
         dataset_model : Optional[aa.DatasetModel] = None,
         adapt_images: Optional[ag.AdaptImages] = None,
         settings_inversion: aa.SettingsInversion = aa.SettingsInversion(),
-        run_time_dict: Optional[Dict] = None,
+        preloads: aa.Preloads = None,
     ):
         """
         Fits an imaging dataset using a `Tracer` object.
@@ -62,12 +62,9 @@ class FitImaging(aa.FitImaging, AbstractFitInversion):
             reconstructed galaxy's morphology.
         settings_inversion
             Settings controlling how an inversion is fitted for example which linear algebra formalism is used.
-        run_time_dict
-            A dictionary which if passed to the fit records how long function calls which have the `profile_func`
-            decorator take to run.
         """
 
-        super().__init__(dataset=dataset, dataset_model=dataset_model, run_time_dict=run_time_dict)
+        super().__init__(dataset=dataset, dataset_model=dataset_model)
         AbstractFitInversion.__init__(
             self=self, model_obj=tracer, settings_inversion=settings_inversion
         )
@@ -76,15 +73,24 @@ class FitImaging(aa.FitImaging, AbstractFitInversion):
 
         self.adapt_images = adapt_images
         self.settings_inversion = settings_inversion
+        self.preloads = preloads
 
     @property
     def blurred_image(self) -> aa.Array2D:
         """
         Returns the image of all light profiles in the fit's tracer convolved with the imaging dataset's PSF.
         """
+
+        if len(self.tracer.cls_list_from(cls=ag.LightProfile)) == len(
+            self.tracer.cls_list_from(cls=ag.lp_operated.LightProfileOperated)
+        ):
+            return self.tracer.image_2d_from(
+                grid=self.grids.lp,
+            )
+
         return self.tracer.blurred_image_2d_from(
             grid=self.grids.lp,
-            convolver=self.dataset.convolver,
+            psf=self.dataset.psf,
             blurring_grid=self.grids.blurring,
         )
 
@@ -93,7 +99,6 @@ class FitImaging(aa.FitImaging, AbstractFitInversion):
         """
         Returns the dataset's image with all blurred light profile images in the fit's tracer subtracted.
         """
-
         return self.data - self.blurred_image
 
     @property
@@ -103,7 +108,7 @@ class FitImaging(aa.FitImaging, AbstractFitInversion):
             data=self.profile_subtracted_image,
             noise_map=self.noise_map,
             grids=self.grids,
-            convolver=self.dataset.convolver,
+            psf=self.dataset.psf,
             w_tilde=self.w_tilde,
         )
 
@@ -112,7 +117,7 @@ class FitImaging(aa.FitImaging, AbstractFitInversion):
             tracer=self.tracer,
             adapt_images=self.adapt_images,
             settings_inversion=self.settings_inversion,
-            run_time_dict=self.run_time_dict
+            preloads=self.preloads,
         )
 
     @cached_property
@@ -163,7 +168,7 @@ class FitImaging(aa.FitImaging, AbstractFitInversion):
 
         galaxy_blurred_image_2d_dict = self.tracer.galaxy_blurred_image_2d_dict_from(
             grid=self.grids.lp,
-            convolver=self.dataset.convolver,
+            psf=self.dataset.psf,
             blurring_grid=self.grids.blurring,
         )
 
