@@ -63,6 +63,7 @@ class VisualizerImaging(af.Visualizer):
         paths: af.DirectoryPaths,
         instance: af.ModelInstance,
         during_analysis: bool,
+        quick_update: bool = False,
     ):
         """
         Output images of the maximum log likelihood model inferred by the model-fit. This function is called throughout
@@ -92,6 +93,32 @@ class VisualizerImaging(af.Visualizer):
         """
 
         fit = analysis.fit_from(instance=instance)
+        tracer = fit.tracer_linear_light_profiles_to_light_profiles
+
+        visuals_2d_of_planes_list = tracer_util.visuals_2d_of_planes_list_from(
+            tracer=fit.tracer,
+            grid=fit.grids.lp.mask.derive_grid.all_false
+        )
+
+
+        plotter_interface = PlotterInterfaceImaging(
+            image_path=paths.image_path,
+            title_prefix=analysis.title_prefix,
+        )
+
+        try:
+            plotter_interface.fit_imaging(
+                fit=fit,
+                visuals_2d_of_planes_list=visuals_2d_of_planes_list,
+                quick_update=quick_update,
+            )
+        except exc.InversionException:
+            pass
+
+        if quick_update:
+            return
+
+        # Full update based on configs.
 
         if analysis.positions_likelihood_list is not None:
 
@@ -111,8 +138,6 @@ class VisualizerImaging(af.Visualizer):
             except exc.InversionException:
                 return
 
-        tracer = fit.tracer_linear_light_profiles_to_light_profiles
-
         zoom = ag.Zoom2D(mask=fit.mask)
 
         extent = zoom.extent_from(buffer=0)
@@ -120,24 +145,6 @@ class VisualizerImaging(af.Visualizer):
 
         grid = ag.Grid2D.from_extent(extent=extent, shape_native=shape_native)
 
-        visuals_2d_of_planes_list = tracer_util.visuals_2d_of_planes_list_from(
-            tracer=fit.tracer,
-            grid=fit.grids.lp.mask.derive_grid.all_false
-        )
-
-        plotter_interface = PlotterInterfaceImaging(
-            image_path=paths.image_path,
-            title_prefix=analysis.title_prefix,
-        )
-
-        try:
-            plotter_interface.fit_imaging(
-                fit=fit,
-                visuals_2d_of_planes_list=visuals_2d_of_planes_list
-            )
-        except exc.InversionException:
-            pass
-
         plotter_interface.tracer(
             tracer=tracer,
             grid=grid,
