@@ -2,8 +2,6 @@ import logging
 import numpy as np
 from typing import Dict, Optional, Tuple, Union
 
-from autoconf.dictable import to_dict
-
 import autofit as af
 import autoarray as aa
 import autogalaxy as ag
@@ -11,8 +9,7 @@ import autogalaxy as ag
 from autoarray.exc import PixelizationException
 
 from autolens.analysis.analysis.dataset import AnalysisDataset
-from autolens.analysis.positions import PositionsLHResample
-from autolens.analysis.positions import PositionsLHPenalty
+from autolens.analysis.positions import PositionsLH
 from autolens.interferometer.model.result import ResultInterferometer
 from autolens.interferometer.model.visualizer import VisualizerInterferometer
 from autolens.interferometer.fit_interferometer import FitInterferometer
@@ -31,11 +28,9 @@ class AnalysisInterferometer(AnalysisDataset):
     def __init__(
         self,
         dataset,
-        positions_likelihood: Optional[
-            Union[PositionsLHResample, PositionsLHPenalty]
-        ] = None,
+        positions_likelihood_list: Optional[PositionsLH] = None,
         adapt_image_maker: Optional[ag.AdaptImageMaker] = None,
-        cosmology: ag.cosmo.LensingCosmology = ag.cosmo.Planck15(),
+        cosmology: ag.cosmo.LensingCosmology = None,
         settings_inversion: aa.SettingsInversion = None,
         raise_inversion_positions_likelihood_exception: bool = True,
         title_prefix: str = None,
@@ -60,10 +55,11 @@ class AnalysisInterferometer(AnalysisDataset):
         ----------
         dataset
             The interferometer dataset that the model is fitted too.
-        positions_likelihood
-            An object which alters the likelihood function to include a term which accounts for whether
-            image-pixel coordinates in arc-seconds corresponding to the multiple images of the lensed source galaxy
-            trace close to one another in the source-plane.
+        positions_likelihood_list
+            Alters the likelihood function to include a term which accounts for whether image-pixel coordinates in
+            arc-seconds corresponding to the multiple images of each lensed source galaxy trace close to one another in
+            their source-plane. This is a list, as it may support multiple planes, where a positions likelihood object
+            is input for each plane (e.g. double source plane lensing).
         adapt_images
             Contains the adapt-images which are used to make a pixelization's mesh and regularization adapt to the
             reconstructed galaxy's morphology.
@@ -72,7 +68,7 @@ class AnalysisInterferometer(AnalysisDataset):
         settings_inversion
             Settings controlling how an inversion is fitted, for example which linear algebra formalism is used.
         raise_inversion_positions_likelihood_exception
-            If an inversion is used without the `positions_likelihood` it is likely a systematic solution will
+            If an inversion is used without the `positions_likelihood_list` it is likely a systematic solution will
             be inferred, in which case an Exception is raised before the model-fit begins to inform the user
             of this. This exception is not raised if this input is False, allowing the user to perform the model-fit
             anyway.
@@ -82,7 +78,7 @@ class AnalysisInterferometer(AnalysisDataset):
         """
         super().__init__(
             dataset=dataset,
-            positions_likelihood=positions_likelihood,
+            positions_likelihood_list=positions_likelihood_list,
             adapt_image_maker=adapt_image_maker,
             cosmology=cosmology,
             settings_inversion=settings_inversion,
@@ -155,34 +151,13 @@ class AnalysisInterferometer(AnalysisDataset):
             The log likelihood indicating how well this model instance fitted the interferometer data.
         """
 
-        try:
-            log_likelihood_positions_overwrite = (
-                self.log_likelihood_positions_overwrite_from(instance=instance)
-            )
-            if log_likelihood_positions_overwrite is not None:
-                return log_likelihood_positions_overwrite
-        except Exception as e:
-            raise e
+        log_likelihood_penalty = self.log_likelihood_penalty_from(instance=instance)
 
-        try:
-            return self.fit_from(instance=instance).figure_of_merit
-        except (
-            PixelizationException,
-            exc.PixelizationException,
-            exc.InversionException,
-            exc.GridException,
-            exc.MeshException,
-            ValueError,
-            TypeError,
-            np.linalg.LinAlgError,
-            OverflowError,
-        ) as e:
-            raise exc.FitException from e
+        return self.fit_from(instance=instance).figure_of_merit - log_likelihood_penalty
 
     def fit_from(
         self,
         instance: af.ModelInstance,
-        run_time_dict: Optional[Dict] = None,
     ) -> FitInterferometer:
         """
         Given a model instance create a `FitInterferometer` object.
@@ -208,7 +183,7 @@ class AnalysisInterferometer(AnalysisDataset):
         """
 
         tracer = self.tracer_via_instance_from(
-            instance=instance, run_time_dict=run_time_dict
+            instance=instance,
         )
 
         adapt_images = self.adapt_images_via_instance_from(instance=instance)
@@ -218,7 +193,6 @@ class AnalysisInterferometer(AnalysisDataset):
             tracer=tracer,
             adapt_images=adapt_images,
             settings_inversion=self.settings_inversion,
-            run_time_dict=run_time_dict,
         )
 
     def save_attributes(self, paths: af.DirectoryPaths):
@@ -260,52 +234,3 @@ class AnalysisInterferometer(AnalysisDataset):
         )
 
         analysis.save_attributes(paths=paths)
-
-        if self.positions_likelihood is not None:
-            paths.save_json(
-                name="positions",
-                object_dict=to_dict(self.positions_likelihood.positions),
-                prefix="dataset",
-            )
-
-    def profile_log_likelihood_function(
-        self, instance: af.ModelInstance, paths: Optional[af.DirectoryPaths] = None
-    ) -> Tuple[Dict, Dict]:
-        """
-        This function is optionally called throughout a model-fit to profile the log likelihood function.
-
-        All function calls inside the `log_likelihood_function` that are decorated with the `profile_func` are timed
-        with their times stored in a dictionary called the `run_time_dict`.
-
-        An `info_dict` is also created which stores information on aspects of the model and dataset that dictate
-        run times, so the profiled times can be interpreted with this context.
-
-        The results of this profiling are then output to hard-disk in the `profiling` folder of the model-fit results,
-        which they can be inspected to ensure run-times are as expected.
-
-        Parameters
-        ----------
-        instance
-            An instance of the model that is being fitted to the data by this analysis (whose parameters have been set
-            via a non-linear search).
-        paths
-            The paths object which manages all paths, e.g. where the non-linear search outputs are stored,
-            visualization and the pickled objects used by the aggregator output by this function.
-
-        Returns
-        -------
-        Two dictionaries, the profiling dictionary and info dictionary, which contain the profiling times of the
-        `log_likelihood_function` and information on the model and dataset used to perform the profiling.
-        """
-        run_time_dict, info_dict = super().profile_log_likelihood_function(
-            instance=instance,
-        )
-
-        info_dict["number_of_visibilities"] = self.dataset.data.shape[0]
-        info_dict["transformer_cls"] = self.dataset.transformer.__class__.__name__
-
-        self.output_profiling_info(
-            paths=paths, run_time_dict=run_time_dict, info_dict=info_dict
-        )
-
-        return run_time_dict, info_dict
