@@ -1,6 +1,5 @@
 from abc import ABC
 import numpy as np
-from functools import wraps
 from scipy.interpolate import griddata
 from typing import Dict, List, Optional, Type, Union
 
@@ -18,8 +17,7 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
     def __init__(
         self,
         galaxies: Union[List[ag.Galaxy], af.ModelInstance],
-        cosmology: ag.cosmo.LensingCosmology = ag.cosmo.Planck15(),
-        run_time_dict: Optional[Dict] = None,
+        cosmology: ag.cosmo.LensingCosmology = None,
     ):
         """
         Performs gravitational lensing ray-tracing calculations based on an input list of galaxies and a cosmology.
@@ -50,16 +48,11 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
             The list of galaxies which make up the gravitational lensing ray-tracing system.
         cosmology
             The cosmology used to perform ray-tracing calculations.
-        run_time_dict
-            A dictionary of information on the run-times of function calls, including the total time and time spent on
-            different calculations.
         """
 
         self.galaxies = galaxies
 
-        self.cosmology = cosmology
-
-        self.run_time_dict = run_time_dict
+        self.cosmology = cosmology or ag.cosmo.Planck15()
 
     @property
     def galaxies_ascending_redshift(self) -> List[ag.Galaxy]:
@@ -142,7 +135,7 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
         line_of_sight_galaxies: List[ag.Galaxy],
         source_galaxies: List[ag.Galaxy],
         planes_between_lenses: List[int],
-        cosmology: ag.cosmo.LensingCosmology = ag.cosmo.Planck15(),
+        cosmology: ag.cosmo.LensingCosmology = None,
     ):
         """
         Returns a tracer where the lens system is split into planes with specified redshift distances between them.
@@ -189,6 +182,7 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
         cosmology
             The cosmology used to perform ray-tracing calculations.
         """
+        cosmology = cosmology or ag.cosmo.Planck15()
 
         lens_redshifts = tracer_util.plane_redshifts_from(galaxies=lens_galaxies)
 
@@ -452,7 +446,6 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
         return image_2d_list
 
     @aa.grid_dec.to_array
-    @aa.profile_func
     def image_2d_from(
         self,
         grid: aa.type.Grid2DLike,
@@ -549,9 +542,9 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
         )[plane_index]
 
         image = griddata(
-            points=plane_grid,
-            values=plane_image,
-            xi=traced_grid.over_sampled,
+            points=plane_grid.array,
+            values=plane_image.array,
+            xi=traced_grid.over_sampled.array,
             fill_value=0.0,
             method="linear",
         )
@@ -760,6 +753,29 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
         """
         return sum([galaxy.potential_2d_from(grid=grid) for galaxy in self.galaxies])
 
+    @aa.grid_dec.to_array
+    def time_delays_from(self, grid: aa.type.Grid2DLike) -> aa.Array2D:
+        """
+        Returns the gravitational lensing time delay in days, for a grid of 2D (y, x) coordinates.
+
+        This function calculates the time delay at each image-plane position due to both geometric and gravitational
+        (Shapiro) effects, as described by the Fermat potential, which are computed using the deflection angles of the
+        galaxies in the lens system.
+
+        Time dleays are computed from a reference point, which is the delay one would compute without a mass model.
+        This means a time delay could be negative, which means the light travel time is faster when lensing is
+        accounted for. When performing fitting, all time-delays are subtracted by the time-delay of the
+        shortest time-delay, such that its value is zero and all other time-delays are positive.
+
+        A full description of the calculation is given in the `autolens.lens.tracer.tracer_util.time_delays_from`
+        function, which performs the calculation and has full latex documentation of the equations used.
+        """
+        return tracer_util.time_delays_from(
+            galaxies=ag.Galaxies(self.galaxies_ascending_redshift),
+            grid=grid,
+            cosmology=self.cosmology,
+        )
+
     def has(self, cls: Type) -> bool:
         """
         Returns a bool specifying whether this tracer has a galaxy with a certain class type.
@@ -801,6 +817,31 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
 
         return cls_list
 
+    def plane_index_via_redshift_from(self, redshift: float) -> Optional[int]:
+        """
+        Returns the index of a plane at a given redshift.
+
+        This is used to determine the index of a plane in the tracer, which is useful for multi-plane ray-tracing
+        calculations. The index of the plane may, for example, be used to extract grid of a specific plane in the
+        tracer after multi-plane ray-tracing calculations.
+
+        A tolerance of 1e-8 is used to determine if the input redshift is close to the redshift of a plane. If
+        no matching plane is found, None is returned.
+
+        Parameters
+        ----------
+        redshift
+            The redshift of the plane to find the index of.
+
+        Returns
+        -------
+            The index of the plane that matches the input redshift.
+        """
+
+        for plane_index, plane_redshift in enumerate(self.plane_redshifts):
+            if np.isclose(redshift, plane_redshift, atol=1e-8):
+                return plane_index
+
     @property
     def plane_indexes_with_pixelizations(self) -> List[int]:
         """
@@ -1141,7 +1182,3 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections):
                             background_sky_level=background_sky_level,
                             psf=psf,
                         )
-
-    @aa.profile_func
-    def convolve_via_convolver(self, image, blurring_image, convolver):
-        return convolver.convolve_image(image=image, blurring_image=blurring_image)
