@@ -13,7 +13,6 @@ from autolens.lens.mock.mock_tracer import MockTracerPoint  # noqa
 from autolens.point.mock.mock_solver import MockPointSolver  # noqa
 
 
-@register_pytree_node_class
 class NullTracer(Tracer):
     def __init__(self):
         super().__init__([])
@@ -28,16 +27,3 @@ class NullTracer(Tracer):
         self, grid, buffer: float = 0.01, deflections_func=None
     ) -> aa.ArrayIrregular:
         return aa.ArrayIrregular(values=jnp.ones(grid.shape[0]))
-
-    def tree_flatten(self):
-        """
-        Flatten this model as a PyTree.
-        """
-        return (), None
-
-    @classmethod
-    def tree_unflatten(cls, aux_data, children):
-        """
-        Unflatten a PyTree into a model.
-        """
-        return cls()
