@@ -33,7 +33,7 @@ class AnalysisPoint(AgAnalysis, AnalysisLens):
         solver: PointSolver,
         fit_positions_cls=FitPositionsImagePairRepeat,
         image=None,
-        cosmology: ag.cosmo.LensingCosmology = ag.cosmo.Planck15(),
+        cosmology: ag.cosmo.LensingCosmology = None,
         title_prefix: str = None,
     ):
         """
@@ -121,17 +121,14 @@ class AnalysisPoint(AgAnalysis, AnalysisLens):
         float
             The log likelihood indicating how well this model instance fitted the imaging data.
         """
-        try:
-            fit = self.fit_from(instance=instance)
-            return fit.log_likelihood
-        except (AttributeError, ValueError, TypeError, NumbaException) as e:
-            raise exc.FitException from e
+        return self.fit_from(instance=instance).log_likelihood
 
     def fit_from(
-        self, instance, run_time_dict: Optional[Dict] = None
+        self,
+        instance,
     ) -> FitPointDataset:
         tracer = self.tracer_via_instance_from(
-            instance=instance, run_time_dict=run_time_dict
+            instance=instance,
         )
         """
         Given a model instance create a `FitPointDataset` object.
@@ -144,8 +141,6 @@ class AnalysisPoint(AgAnalysis, AnalysisLens):
         instance
             An instance of the model that is being fitted to the data by this analysis (whose parameters have been set
             via a non-linear search).
-        run_time_dict
-            A dictionary which times functions called to fit the model to data, for profiling.
 
         Returns
         -------
@@ -156,7 +151,6 @@ class AnalysisPoint(AgAnalysis, AnalysisLens):
             tracer=tracer,
             solver=self.solver,
             fit_positions_cls=self.fit_positions_cls,
-            run_time_dict=run_time_dict,
         )
 
     def save_attributes(self, paths: af.DirectoryPaths):
